# Overview

An events framework that allows for logging and processing of Django models custom events.

# Setup

## Requirements

* Python 3.9+

## Installation

Install it directly into an activated virtual environment:

```text
$ pip install django-events-framework
```

# Usage

After installation, the framework can be used by:

```text
INSTALLED_APPS = [
    ...,
    "events_framework"
]
```